Package 'kwb.budget'

Title: R Package for Aggregating and Analysing Budget Excel Files from Project Partners
Description: R package useful during project development (e.g. H2020 calls with many project partners). By using a budget EXCEL template file, data received from the different partners can be aggregated and analysed.)
Authors: Hauke Sonnenberg [aut, cre] (ORCID: <https://orcid.org/0000-0001-9134-2871>), Michael Rustler [aut] (ORCID: <https://orcid.org/0000-0003-0647-7726>), Kompetenzzentrum Wasser Berlin gGmbH (KWB) [cph]
Maintainer: Hauke Sonnenberg <[email protected]>
License: MIT + file LICENSE
Version: 0.0.0.9000
Built: 2026-05-15 09:21:40 UTC
Source: https://github.com/KWB-R/kwb.budget

Help Index


Helper function: append zero costs

Description

Helper function: append zero costs

Usage

append_zero_costs(x, n_work_packages)

Arguments

x

x

n_work_packages

number of work packages in EXCEL template (default: 7, as used for DWC)

Value

data frame with zero costs


Create partners budget files (for DWH)

Description

Create partners budget files (for DWH)

Usage

create_partners_budget_files(
  path_partners,
  path_budget_template,
  project_shortname = "DWH",
  target_dir = file.path(dirname(path_budget_template), "10_Filled_out_forms"),
  set_values = FALSE,
  overwrite = TRUE
)

Arguments

path_partners

path to partners budget metadata EXCEL file

path_budget_template

path to budget template EXCEL file

project_shortname

proposal acronym (default: "DWH")

target_dir

target directory where to save the budget files (default: file.path(dirname(path_budget_template), "10_Filled_out_forms"))

set_values

should metadata from partners EXCEL file be set or just the template budget EXCEL file copied

overwrite

should existing EXCEL files be overwritten (default: TRUE)

Value

budget excel files for each project partner


Helper function: prepare costs by sector

Description

Helper function: prepare costs by sector

Usage

get_costs_by_sector(costs_overview)

Arguments

costs_overview

costs data

Value

df with costs by type (e.g. health, water, it, ..)


Helper function: prepare costs by type

Description

Helper function: prepare costs by type

Usage

get_costs_by_type(costs_overview)

Arguments

costs_overview

costs data

Value

df with costs by type (e.g. SME, research, ..)


Get Costs by Work Package

Description

Get Costs by Work Package

Usage

get_costs_by_work_package(costs_list, n_work_packages = 7)

Arguments

costs_list

list with "costs" from multiple partner Excelsheets

n_work_packages

number of work packages in EXCEL template (default: 7, as used for DWC)

Value

data frame with costs per work package


Helper function: get named Excel ranges

Description

Helper function: get named Excel ranges

Usage

get_named_excel_ranges(file)

Arguments

file

full path to EXCEL file

Value

named Excel ranges


List the Partner's File Versions (Except Current)

Description

List the Partner's File Versions (Except Current)

Usage

list_partner_budget_versions()

Read Partner Budget From Excel File

Description

Read Partner Budget From Excel File

Usage

read_partner_budget_from_excel(file, n_work_packages = 7, dbg = TRUE)

Arguments

file

full path to EXCEL file

n_work_packages

number of work packages in EXCEL template (default: 7, as used for DWC)

dbg

debug message (default: TRUE)

Value

list with imported EXCEL budget file data


Read Partners Budget From Excel Files

Description

Read Partners Budget From Excel Files

Usage

read_partners_budget_from_excel(
  files,
  n_work_packages = 7,
  run_parallel = TRUE
)

Arguments

files

full path to EXCEL files

n_work_packages

number of work packages in EXCEL template (default: 7, as used for DWC)

run_parallel

should import be performed using multiple CPU cores or only run on a single core (default: TRUE)

Value

list with imported EXCEL budget files data